/* Copyright (c) 2015 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

#include "nrf_drv_spi.h"
#include "app_util_platform.h"
#include "nrf_gpio.h"
#include "nrf_delay.h"
#include "nrf_log.h"
#include "boards.h"
#include "app_error.h"
#include <string.h>
					/**********UART**********/
#include <stdbool.h>
#include <stdint.h>
#include <stdio.h>
#include "app_uart.h"
#include "app_error.h"
#include "nrf_delay.h"
#include "nrf.h"
#include "bsp.h"

#define ENABLE_LOOPBACK_TEST  /**< if defined, then this example will be a loopback test, which means that TX should be connected to RX to get data loopback. */

#define MAX_TEST_DATA_BYTES     (15U)                /**< max number of test bytes to be used for tx and rx. */
#define UART_TX_BUF_SIZE 256                         /**< UART TX buffer size. */
#define UART_RX_BUF_SIZE 1                           /**< UART RX buffer size. */

					/********************/
// #include "nrf_gpio.h"
// #include "boards.h"
#include "LIS2DH_simple.h"
#include "nrf51_bitfields.h"
#include "nrf_delay.h"	
#include "flashboard.h"				
					/*************LIS2DH*************/
					
#if defined(BOARD_PCA10036) || defined(BOARD_PCA10040)
#define SPI_CS_PIN   29 /**< SPI CS Pin.*/
#elif defined(BOARD_PCA10028)
#define SPI_CS_PIN   4  /**< SPI CS Pin.*/
#else
#error "Example is not supported on that board."
#endif

#define SPI_INSTANCE  0 /**< SPI instance index. */
static const nrf_drv_spi_t spi = NRF_DRV_SPI_INSTANCE(SPI_INSTANCE);  /**< SPI instance. */
static volatile bool spi_xfer_done;  /**< Flag used to indicate that SPI instance completed the transfer. */

#define TEST_STRING "Nordic"
static uint8_t       m_tx_buf[] = TEST_STRING;           /**< TX buffer. */
//static uint8_t       m_rx_buf[sizeof(TEST_STRING)+1];    /**< RX buffer. */
static const uint8_t m_length = sizeof(m_tx_buf);        /**< Transfer length. */

				/********************/

				/**********UART**********/
void uart_error_handle(app_uart_evt_t * p_event)
{
    if (p_event->evt_type == APP_UART_COMMUNICATION_ERROR)
    {
        APP_ERROR_HANDLER(p_event->data.error_communication);
    }
    else if (p_event->evt_type == APP_UART_FIFO_ERROR)
    {
        APP_ERROR_HANDLER(p_event->data.error_code);
    }
}
			/**********************LIS2DH**************************/
void ACCEL_SPI_INIT(){
	//set up gpio
	nrf_gpio_cfg_output(SPI_CS);
	nrf_gpio_cfg_output(SPI_MOSI);
	nrf_gpio_cfg_output(SPI_CLK);
	nrf_gpio_cfg_input(SPI_MISO, NRF_GPIO_PIN_NOPULL);

	//Mosi should be low
	nrf_gpio_pin_clear(SPI_MOSI);
	//CS high, as it is active low
	nrf_gpio_pin_set(SPI_CS);

	//set up spi peripheral
	// NRF_SPI0 -> ENABLE    =  SPI_ENABLE_ENABLE_ENABLED  << SPI_ENABLE_ENABLE_POS; //enable spi peripheral
	// NRF_SPI0 -> PSELSCK   =  SPI_CLK;
	// NRF_SPI0 -> PSELMOSI  =  SPI_MOSI;
	// NRF_SPI0 -> PSELMISO  =  SPI_MISO;
	// NRF_SPI0 -> FREQUENCY =  SPI_FREQUENCY_FREQUENCY_M8 << SPI_FREQUENCY_FREQUENCY_POS;  //8Mbps
	// NRF_SPI0 -> CONFIG    =	 SPI_CONFIG_ORDER_MsbFirst  << SPI_CONFIG_ORDER_POS
	// 						|SPI_CONFIG_CPHA_Leading    << SPI_CONFIG_CPHA_POS
	// 						|SPI_CONFIG_CPOL_ActiveHigh << SPI_CONFIG_CPOL_POS;

	NRF_SPI0 -> ENABLE    =  0x01UL  << 0x00UL; //enable spi peripheral
	NRF_SPI0 -> PSELSCK   =  SPI_CLK;
	NRF_SPI0 -> PSELMOSI  =  SPI_MOSI;
	NRF_SPI0 -> PSELMISO  =  SPI_MISO;
	NRF_SPI0 -> FREQUENCY =  0x80000000UL << 0x00UL;  //8Mbps
	NRF_SPI0 -> CONFIG    =	 0x00UL  << 0x00UL
							|0x00UL    << 0x01UL
							|0x00UL << 0x2UL;
}

//select chip
void SEL_CS(){
	nrf_gpio_pin_clear(SPI_CS);
	nrf_delay_ms(1);
}

//release chip
void REL_CS(){
	nrf_delay_ms(1);
	nrf_gpio_pin_set(SPI_CS);
}

//send a byte, get a byte
void SPI_TXRX(uint8_t* transmit, uint8_t* receive, uint8_t bufsize){
	SEL_CS();
	for(int i = 0; i<bufsize; i++){
		NRF_SPI0 -> TXD = transmit[i];
		while(NRF_SPI0 -> EVENTS_READY == 0){
			//nop a bit
		}
		NRF_SPI0 -> EVENTS_READY = 0; //set event flag back to zee ro
		receive[i] = NRF_SPI0 -> RXD; //put the rx byte in the buf		
	}
	REL_CS();
}

void reg_write(uint8_t reg, uint8_t val){
	uint8_t out[2];
    uint8_t in[2];

    in[0]=reg;// set read bit to "write", with no reg increments
    in[1]=val;// the val to set it to
    SPI_TXRX(in,out,2);//do the thing
}



uint8_t reg_read(uint8_t reg){
    uint8_t in[2];
    uint8_t out[2];

    in[0]=reg | 0x80;// set read bit to "read", with no reg increments
    in[1]=0x00;      // no data
	
    SPI_TXRX(in,out,2);//do the thing

    return out[1];
}

uint8_t reg_write_ver(uint8_t reg, uint8_t val){
	reg_write(reg, val);

	if(reg_read(reg)!=val){
		return 0;
	}
	else{
		return 1;
	}
}


//updates a location in memory that should hold the XYZ accelerations
void update_xyz(uint16_t* xyz){	
	uint8_t bottom;
	uint8_t top;
    
    bottom = reg_read(OUT_X_L);
    nrf_delay_us(1);
    top = reg_read(OUT_X_H);
    xyz[0] =  (uint16_t) top<<8 | (uint16_t) bottom;
	if(xyz[0] == true)
	while(app_uart_put(xyz[0]) != NRF_SUCCESS);
    nrf_delay_us(1);

    bottom = reg_read(OUT_Y_L);
    nrf_delay_us(1);
    top = reg_read(OUT_Y_H);
    xyz[1] =  (uint16_t) top<<8 | (uint16_t) bottom;
		if(xyz[1] == true)
	while(app_uart_put(xyz[1]) != NRF_SUCCESS);
    nrf_delay_us(1);

    bottom = reg_read(OUT_Z_L);
    nrf_delay_us(1);
    top = reg_read(OUT_Z_H);
    xyz[2] =  (uint16_t) top<<8 | (uint16_t) bottom;
		if(xyz[2] == true)
	while(app_uart_put(xyz[2]) != NRF_SUCCESS);
    nrf_delay_us(1);

}
					/**********************************************/
				
int main(void)
{
	//uint16_t xyz[3];
	uint8_t xl, yl, zl;
	uint8_t xh, yh, zh;
	
    uint32_t err_code;
    const app_uart_comm_params_t comm_params =
      {
          RX_PIN_NUMBER,
          TX_PIN_NUMBER,
          RTS_PIN_NUMBER,
          CTS_PIN_NUMBER,
          APP_UART_FLOW_CONTROL_DISABLED,
          false,
          UART_BAUDRATE_BAUDRATE_Baud115200
      };

    APP_UART_FIFO_INIT(&comm_params,
                         UART_RX_BUF_SIZE,
                         UART_TX_BUF_SIZE,
                         uart_error_handle,
                         APP_IRQ_PRIORITY_LOW,
                         err_code);

    APP_ERROR_CHECK(err_code);
				/******************************/
					
				
	ACCEL_SPI_INIT();   // SPI Initialization fpr Accelerometer sensor
		
    while(1)
    {

	xl = reg_read(OUT_X_L);
	if(xl == true)
	while(app_uart_put(xl) != NRF_SUCCESS);
	
	yl = reg_read(OUT_Y_L);
	if(yl == true)
	while(app_uart_put(yl) != NRF_SUCCESS);

	zl = reg_read(OUT_Z_L);
	if(zl == true)
	while(app_uart_put(zl) != NRF_SUCCESS);
	
	xh = reg_read(OUT_X_H);
	if(xh == true)
	while(app_uart_put(xh) != NRF_SUCCESS);

	
	yh = reg_read(OUT_Y_H);
	if(yh == true)
	while(app_uart_put(yh) != NRF_SUCCESS);
	
	zh = reg_read(OUT_Z_H);
	if(zh == true)
	while(app_uart_put(zh) != NRF_SUCCESS);

    }
}

Q: 

    